@@ -8,7 +8,7 @@
 
     This file is part of fs_filepicker.
 
-    :copyright: Copyright 2017 Reimar Bauer
+    :copyright: Copyright 2017-2018 Reimar Bauer
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -23,7 +23,7 @@
     See the License for the specific language governing permissions and
     limitations under the License.
 """
-import os
+
 import sys
 import time
 import logging
@@ -48,9 +48,9 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
                  default_filename=None, show_save_action=False, show_dirs_only=False):
         super(FilePicker, self).__init__(parent)
         frame = inspect.stack()[1][0]
-        scope = who_called_me(frame)
+        self.scope = who_called_me(frame)
         self.setupUi(self)
-        self.settings = QSettings("fs_filepicker", scope)
+        self.settings = QSettings("fs_filepicker", self.scope)
         self.setWindowIcon(QIcon(icons('fs_logo.png', origin='fs')))
         self.file_icon = icons('text-x-generic.png')
         self.dir_icon = icons('folder.png')
@@ -164,7 +164,8 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         self.ui_root.setIcon(QIcon(icons('computer.png')))
         self.ui_fs.setText("")
         self.ui_fs.setIconSize(QtCore.QSize(64, 64))
-        self.ui_fs.setIcon(QIcon(icons('fs_logo.png', origin=u'fs')))
+        if self.scope == u"fs_filepicker":
+            self.ui_fs.setIcon(QIcon(icons('fs_logo.png', origin=u'fs')))
         self.ui_other_fs.setText("")
         self.ui_other_fs.setIconSize(QtCore.QSize(64, 64))
         self.ui_other_fs.setIcon(QIcon(icons('goto-other-computer.png')))
@@ -594,7 +595,7 @@ def fs_filepicker(parent=None, fs_url=u'~/', file_pattern=u'All Files (*)', titl
         if dirname.startswith(fp.active_url):
             filename = u"{}{}".format(active_url, fp.filename)
         else:
-            filename = os.path.abspath(fs.path.combine(u"{}{}".format(active_url, dirname), fp.filename))
+            filename = fs.path.abspath(fs.path.join(u"{}{}".format(active_url, dirname), fp.filename))
     return filename, fp.selected_file_pattern[0]
 
 
